import { usePathname } from "next/navigation";
import { useSession } from "next-auth/react";
import { Link } from "@/shared/config/navigation";
import { useTranslations } from "next-intl";

interface INavAuthProps {
  responsible?: boolean;
  setOpenMenu: (open: boolean) => void;
}

const NavAuth: React.FC<INavAuthProps> = ({
  responsible,
  setOpenMenu,
}: INavAuthProps) => {
  const t = useTranslations("navigation");
  const session = useSession();
  const auth = session.status === "authenticated" ? true : false;

  const pathname = usePathname();
  const isActiveProfile = pathname === "/profile";
  const isActiveSignIn = pathname === "/sign-in";

  return (
    <>
      {auth ? (
        <Link
          onClick={() => setOpenMenu(false)}
          href="/profile/personal"
          className={`${
            responsible
              ? `w-fit px-5 py-3 border-3 rounded-lg font-semibold transition-colors duration-300 ${"bg-[#3695d8] text-white"}`
              : "w-fit px-5 py-3 border-3 rounded-lg font-semibold transition-colors duration-300 bg-[#3695d8] text-white border-[#3695d8]"
          }`}
        >
          {t("profile")}
        </Link>
      ) : (
        <Link
          onClick={() => setOpenMenu(false)}
          href="/sign-in"
          className={`${
            responsible
              ? `w-fit px-5 py-3 border-3 rounded-lg font-semibold transition-colors duration-300 ${
                  isActiveSignIn
                    ? "bg-[#3695d8] text-white"
                    : "bg-white text-[#3695d8] border-[#3695d8]"
                }`
              : "w-fit px-5 py-3 border-3 rounded-lg font-semibold transition-colors duration-300 bg-[#3695d8] text-white"
          }`}
        >
          {t("login")}
        </Link>
      )}
    </>
  );
};

export default NavAuth;
